==> huaweicloudsdkdataartsstudio-3.1.68-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/list_apic_groups_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListApicGroupsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'gateway_groups': 'list[ApigGroupDTO]'
    }

    attribute_map = {
        'gateway_groups': 'gateway_groups'
    }

    def __init__(self, gateway_groups=None):
        """ListApicGroupsResponse

        The model defined in huaweicloud sdk

        :param gateway_groups: 网关分组列表
        :type gateway_groups: list[:class:`huaweicloudsdkdataartsstudio.v1.ApigGroupDTO`]
        """
        
        super(ListApicGroupsResponse, self).__init__()

        self._gateway_groups = None
        self.discriminator = None

        if gateway_groups is not None:
            self.gateway_groups = gateway_groups

    @property
    def gateway_groups(self):
        """Gets the gateway_groups of this ListApicGroupsResponse.

        网关分组列表

        :return: The gateway_groups of this ListApicGroupsResponse.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.ApigGroupDTO`]
        """
        return self._gateway_groups

    @gateway_groups.setter
    def gateway_groups(self, gateway_groups):
        """Sets the gateway_groups of this ListApicGroupsResponse.

        网关分组列表

        :param gateway_groups: The gateway_groups of this ListApicGroupsResponse.
        :type gateway_groups: list[:class:`huaweicloudsdkdataartsstudio.v1.ApigGroupDTO`]
        """
        self._gateway_groups = gateway_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListApicGroupsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/list_apic_groups_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListApicGroupsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'gateway_groups': 'list[ApigGroupDTO]'
    }

    attribute_map = {
        'gateway_groups': 'gateway_groups'
    }

    def __init__(self, gateway_groups=None):
        r"""ListApicGroupsResponse

        The model defined in huaweicloud sdk

        :param gateway_groups: 网关分组列表
        :type gateway_groups: list[:class:`huaweicloudsdkdataartsstudio.v1.ApigGroupDTO`]
        """
        
        super(ListApicGroupsResponse, self).__init__()

        self._gateway_groups = None
        self.discriminator = None

        if gateway_groups is not None:
            self.gateway_groups = gateway_groups

    @property
    def gateway_groups(self):
        r"""Gets the gateway_groups of this ListApicGroupsResponse.

        网关分组列表

        :return: The gateway_groups of this ListApicGroupsResponse.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.ApigGroupDTO`]
        """
        return self._gateway_groups

    @gateway_groups.setter
    def gateway_groups(self, gateway_groups):
        r"""Sets the gateway_groups of this ListApicGroupsResponse.

        网关分组列表

        :param gateway_groups: The gateway_groups of this ListApicGroupsResponse.
        :type gateway_groups: list[:class:`huaweicloudsdkdataartsstudio.v1.ApigGroupDTO`]
        """
        self._gateway_groups = gateway_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListApicGroupsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
